@@ -60,6 +60,15 @@ ACTION_SYMBOLS = {
     "delete": "🛑",
 }
 
+ACTION_TEXT = {
+    "no-op": ".",
+    "create": "+",
+    "read": "r",
+    "update": "U",
+    "replace": "R",
+    "delete": "X",
+}
+
 HEADER = """
 **Terraform Plan changes summary:**
 ===================================
@@ -69,30 +78,34 @@ FOOTER = """
 """
 
 
-def getAction(actions):
+def getAction(actions, textonly):
     """
     Get action
 
     Args:
         actions(list): list of actions
+        textonly(bool): disable emoji
 
     Returns:
         action symbol
     """
 
     logger.debug("get action")
+    lookup = ACTION_TEXT if textonly else ACTION_SYMBOLS
+
     if "create" in actions and len(actions) > 1:
-        return ACTION_SYMBOLS["replace"]
+        return lookup["replace"]
     else:
-        return ACTION_SYMBOLS[actions[0]]
+        return lookup[actions[0]]
 
 
-def parseChanges(changes):
+def parseChanges(changes, textonly):
     """
     Parse changes.
 
     Args:
         changes(list): list of resources dict
+        textonly(bool): disable emoji
 
     Returns:
         Multiline string with summary of changes
@@ -101,7 +114,7 @@ def parseChanges(changes):
     content = ""
     logger.debug("parsing changes...")
     for c in changes:
-        action = getAction(c["actions"])
+        action = getAction(c["actions"], textonly)
         message = "({action}): {name} ({address})".format(
             action=action, name=c["name"], address=c["address"]
         )
@@ -234,13 +247,14 @@ def sendRequest(url, data, azdo):
     return response.status_code
 
 
-def generate_pr_comment(changes, azdo):
+def generate_pr_comment(changes, azdo, textonly=False):
     """
     Handles changes and formats content to send to Azure DevOps API.
 
     Args:
         changes(list): list of resources dict
         azdo(dict): Azure DevOps parameters
+        textonly(bool): disable emoji
     """
 
     ret = False
@@ -250,7 +264,7 @@ def generate_pr_comment(changes, azdo):
         commentType = COMMENTTYPE["TEXT"]
         statusCode = COMMENTTHREADSTATUS["CLOSED"]
     else:
-        content = parseChanges(changes)
+        content = parseChanges(changes, textonly)
         commentType = COMMENTTYPE["CODECHANGE"]
         statusCode = COMMENTTHREADSTATUS["ACTIVE"]
     data = formatDataToSend(content, commentType, statusCode)
